import React from 'react';
type SignalTrackingHooks = {
    onSignalMount(id: string): void;
    onSignalOpen(id: string): void;
    onSignalLinkClick(id: string): void;
    onSignalPrimaryActionClick(id: string): void;
    onSignalClose(id: string): void;
};
declare const SignalHooksProvider: React.FunctionComponent<Partial<SignalTrackingHooks>>;
export type Signal = {
    /**
     * Unique signal id that will be used to resolve the dismissing logic.
     * If signal was dismissed before and should stay dismissed, it will
     * not be rendered when passed to the component
     */
    id: string;
    title: React.ReactNode;
    description: React.ReactNode;
    learnMoreLink: string;
    /**
     * Optional, default is "Learn more"
     */
    learnMoreLabel?: string;
    /**
     * Optional, will render a primary action button for a signal when provided
     */
    primaryActionButtonLabel?: string;
    primaryActionButtonIcon?: string;
    primaryActionButtonVariant?: 'primaryOutline' | 'dangerOutline';
    /**
     * Optional, when provided the primary action button will behave as a link.
     */
    primaryActionButtonLink?: string;
    /**
     * Optional, when provided will be called with a signal id on primary action
     * button click
     */
    onPrimaryActionButtonClick?: React.MouseEventHandler;
};
type SignalPopoverProps = {
    /** List of signals to render */
    signals: Signal | Signal[];
    darkMode?: boolean;
    onPopoverOpenChange?: (open: boolean) => void;
    className?: string;
};
declare const SignalPopover: React.FunctionComponent<SignalPopoverProps>;
export { SignalPopover, SignalHooksProvider };
//# sourceMappingURL=signal-popover.d.ts.map